@@ -29,33 +29,30 @@ def set_cam_type(device_type):
 
 
 def all_devices():
-    return (
-        "["
-        + IRCAMERA.device(
+    return [
+        IRCAMERA.device(
             devid=IRCAMERA.DEVICE_ID,
             status=CONST.STATUS_ONLINE,
             low_battery=False,
             no_response=False,
-        )
-        + ","
-        + IPCAM.device(
+        ),
+        IPCAM.device(
             devid=IPCAM.DEVICE_ID,
             status=CONST.STATUS_ONLINE,
             low_battery=False,
             no_response=False,
-        )
-        + "]"
-    )
+        ),
+    ]
 
 
 @pytest.fixture(autouse=True)
 def setup_URLs(m):
     # Set up mock URLs
-    m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-    m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-    m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-    m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
-    m.get(CONST.DEVICES_URL, text=all_devices())
+    m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+    m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+    m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+    m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+    m.get(CONST.DEVICES_URL, json=all_devices())
 
 
 class TestCamera:
@@ -86,7 +83,7 @@ class TestCamera:
             # Change device properties
             m.get(
                 device_url,
-                text=cam_type.device(
+                json=cam_type.device(
                     devid=cam_type.DEVICE_ID,
                     status=CONST.STATUS_OFFLINE,
                     low_battery=True,
@@ -119,13 +116,13 @@ class TestCamera:
                 url = cam_type.CONTROL_URL
 
             # Set up capture URL response
-            m.put(url, text=MOCK.generic_response_ok())
+            m.put(url, json=MOCK.generic_response_ok())
 
             # Capture an image
             assert device.capture()
 
             # Change capture URL responses
-            m.put(url, text=cam_type.get_capture_timeout(), status_code=600)
+            m.put(url, json=cam_type.get_capture_timeout(), status_code=600)
 
             # Capture an image with a failure
             assert not device.capture()
@@ -154,7 +151,7 @@ class TestCamera:
             # Set up timeline response
             url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=device.device_id)
 
-            m.get(url, text="[" + cam_type.timeline_event(device.device_id) + "]")
+            m.get(url, json=[cam_type.timeline_event(device.device_id)])
             # Set up our file path response
             m.head(
                 cam_type.FILE_PATH,
@@ -188,9 +185,7 @@ class TestCamera:
             url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=device.device_id)
             m.get(
                 url,
-                text="["
-                + cam_type.timeline_event(device.device_id, file_path="")
-                + "]",
+                json=[cam_type.timeline_event(device.device_id, file_path="")],
             )
 
             with pytest.raises(jaraco.abode.AbodeException):
@@ -200,9 +195,7 @@ class TestCamera:
             url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=device.device_id)
             m.get(
                 url,
-                text="["
-                + cam_type.timeline_event(device.device_id, event_code="1234")
-                + "]",
+                json=[cam_type.timeline_event(device.device_id, event_code="1234")],
             )
 
             with pytest.raises(jaraco.abode.AbodeException):
@@ -217,7 +210,7 @@ class TestCamera:
 
             # Set up timeline response
             url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=device.device_id)
-            m.get(url, text="[]")
+            m.get(url, json=[])
 
             # Refresh the image
             assert not device.refresh_image()
@@ -235,7 +228,7 @@ class TestCamera:
 
             # Set up timeline response
             url = CONST.TIMELINE_IMAGES_ID_URL.format(device_id=device.device_id)
-            m.get(url, text="[" + cam_type.timeline_event(device.device_id) + "]")
+            m.get(url, json=[cam_type.timeline_event(device.device_id)])
 
             # Set up our file path response
             m.head(
@@ -246,7 +239,7 @@ class TestCamera:
 
             # Set up our image response
             image_response = "this is a beautiful jpeg image"
-            m.get(cam_type.LOCATION_HEADER, text=image_response)
+            m.get(cam_type.LOCATION_HEADER, json=image_response)
 
             # Refresh the image
             path = "test.jpg"
@@ -263,7 +256,7 @@ class TestCamera:
                 device.image_to_file(path, get_image=True)
 
             # Test that the image fails to update returns False
-            m.get(url, text="[]")
+            m.get(url, json=[])
             assert not device.image_to_file(path, get_image=True)
 
     def tests_camera_snapshot(self, m):
@@ -280,17 +273,17 @@ class TestCamera:
             snapshot_url = (
                 f"{CONST.CAMERA_INTEGRATIONS_URL}{device.device_uuid}/snapshot"
             )
-            m.post(snapshot_url, text='{"base64Image":"test"}')
+            m.post(snapshot_url, json=dict(base64Image='test'))
 
             # Retrieve a snapshot
             assert device.snapshot()
 
             # Failed snapshot retrieval due to timeout response
-            m.post(snapshot_url, text=cam_type.get_capture_timeout(), status_code=600)
+            m.post(snapshot_url, json=cam_type.get_capture_timeout(), status_code=600)
             assert not device.snapshot()
 
             # Failed snapshot retrieval due to missing data
-            m.post(snapshot_url, text="{}")
+            m.post(snapshot_url, json={})
             assert not device.snapshot()
 
     def tests_camera_snapshot_write(self, m):
@@ -309,7 +302,7 @@ class TestCamera:
             )
             image_response = b"this is a beautiful jpeg image"
             b64_image = str(base64.b64encode(image_response), "utf-8")
-            m.post(snapshot_url, text='{"base64Image":"' + b64_image + '"}')
+            m.post(snapshot_url, json=dict(base64Image=b64_image))
 
             # Request the snapshot and write to file
             path = "test.jpg"
@@ -321,7 +314,7 @@ class TestCamera:
             os.remove(path)
 
             # Test that bad response returns False
-            m.post(snapshot_url, text=cam_type.get_capture_timeout(), status_code=600)
+            m.post(snapshot_url, json=cam_type.get_capture_timeout(), status_code=600)
             assert not device.snapshot_to_file(path, get_snapshot=True)
 
     def tests_camera_snapshot_data_url(self, m):
@@ -340,7 +333,7 @@ class TestCamera:
             )
             image_response = b"this is a beautiful jpeg image"
             b64_image = str(base64.b64encode(image_response), "utf-8")
-            m.post(snapshot_url, text='{"base64Image":"' + b64_image + '"}')
+            m.post(snapshot_url, json=dict(base64Image=b64_image))
 
             # Request the snapshot as a data url
             data_url = device.snapshot_data_url(get_snapshot=True)
@@ -352,7 +345,7 @@ class TestCamera:
             assert decoded == image_response
 
             # Test that bad response returns an empty string
-            m.post(snapshot_url, text=cam_type.get_capture_timeout(), status_code=600)
+            m.post(snapshot_url, json=cam_type.get_capture_timeout(), status_code=600)
             assert device.snapshot_data_url(get_snapshot=True) == ""
 
     def tests_camera_privacy_mode(self, m):
@@ -364,13 +357,13 @@ class TestCamera:
         assert device.status == CONST.STATUS_ONLINE
 
         # Set up params URL response for privacy mode on
-        m.put(CONST.PARAMS_URL + device.device_id, text=IPCAM.device(privacy=1))
+        m.put(CONST.PARAMS_URL + device.device_id, json=IPCAM.device(privacy=1))
 
         # Set privacy mode on
         assert device.privacy_mode(True)
 
         # Set up params URL response for privacy mode off
-        m.put(CONST.PARAMS_URL + device.device_id, text=IPCAM.device(privacy=0))
+        m.put(CONST.PARAMS_URL + device.device_id, json=IPCAM.device(privacy=0))
 
         # Set privacy mode off
         assert device.privacy_mode(False)
