@@ -1,6 +1,4 @@
 """Test the Abode device classes."""
-import json
-
 import pytest
 
 import jaraco.abode
@@ -39,7 +37,7 @@ class TestDevice:
     def tests_device_mapping_typetag(self):
         """Check the generic Abode device maps to none without typetag."""
         # Set up device
-        device_text = GLASS.device(
+        device = GLASS.device(
             status=CONST.STATUS_ONLINE,
             low_battery=True,
             no_response=True,
@@ -47,24 +45,22 @@ class TestDevice:
             out_of_order=True,
         )
 
-        device_json = json.loads(device_text)
+        with pytest.raises(jaraco.abode.AbodeException):
+            device['type_tag'] = ""
+            jaraco.abode.new_device(device, self.abode)
 
         with pytest.raises(jaraco.abode.AbodeException):
-            device_json['type_tag'] = ""
-            jaraco.abode.new_device(device_json, self.abode)
+            device['type_tag'] = None
+            jaraco.abode.new_device(device, self.abode)
 
         with pytest.raises(jaraco.abode.AbodeException):
-            device_json['type_tag'] = None
-            jaraco.abode.new_device(device_json, self.abode)
-
-        with pytest.raises(jaraco.abode.AbodeException):
-            del device_json['type_tag']
-            jaraco.abode.new_device(device_json, self.abode)
+            del device['type_tag']
+            jaraco.abode.new_device(device, self.abode)
 
     def tests_device_auto_naming(self):
         """Check the generic Abode device creates a name."""
         # Set up device
-        device_text = GLASS.device(
+        source = GLASS.device(
             status=CONST.STATUS_ONLINE,
             low_battery=True,
             no_response=True,
@@ -72,35 +68,32 @@ class TestDevice:
             out_of_order=True,
         )
 
-        device_json = json.loads(device_text)
-
-        device_json['name'] = ""
-        device = jaraco.abode.new_device(device_json, self.abode)
+        source['name'] = ""
+        device = jaraco.abode.new_device(source, self.abode)
         generated_name = device.type + ' ' + device.device_id
         assert device.name == generated_name
 
-        device_json['name'] = None
-        device = jaraco.abode.new_device(device_json, self.abode)
+        source['name'] = None
+        device = jaraco.abode.new_device(source, self.abode)
         generated_name = device.type + ' ' + device.device_id
         assert device.name == generated_name
 
-        del device_json['name']
-        device = jaraco.abode.new_device(device_json, self.abode)
+        del source['name']
+        device = jaraco.abode.new_device(source, self.abode)
         generated_name = device.type + ' ' + device.device_id
         assert device.name == generated_name
 
     def tests_device_init(self, m):
         """Check the generic Abode device class init's properly."""
         # Set up URLs
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok())
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
 
         # Set up device
-        device_text = (
-            '['
-            + GLASS.device(
+        source = [
+            GLASS.device(
                 status=CONST.STATUS_ONLINE,
                 low_battery=True,
                 no_response=True,
@@ -108,11 +101,9 @@ class TestDevice:
                 out_of_order=True,
                 uuid='testuuid00000001',
             )
-            + ']'
-        )
-        device_json = json.loads(device_text)
+        ]
 
-        m.get(CONST.DEVICES_URL, text=device_text)
+        m.get(CONST.DEVICES_URL, json=source)
 
         # Logout to reset everything
         self.abode.logout()
@@ -123,11 +114,11 @@ class TestDevice:
         # Check device states match
         assert device is not None
 
-        assert device.name == device_json[0]['name']
-        assert device.type == device_json[0]['type']
-        assert device.type_tag == device_json[0]['type_tag']
-        assert device.device_id == device_json[0]['id']
-        assert device.device_uuid == device_json[0]['uuid']
+        assert device.name == source[0]['name']
+        assert device.type == source[0]['type']
+        assert device.type_tag == source[0]['type_tag']
+        assert device.device_id == source[0]['id']
+        assert device.device_uuid == source[0]['uuid']
         assert device.status == CONST.STATUS_ONLINE
         assert device.battery_low
         assert device.no_response
@@ -138,19 +129,17 @@ class TestDevice:
     def tests_generic_device_refresh(self, m):
         """Check the generic Abode device class init's properly."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok())
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
 
         # Set up online device
-        device_text_online = '[' + GLASS.device(status=CONST.STATUS_ONLINE) + ']'
-        m.get(CONST.DEVICES_URL, text=device_text_online)
+        m.get(CONST.DEVICES_URL, json=[GLASS.device(status=CONST.STATUS_ONLINE)])
 
         # Set up offline device
-        device_text_offline = '[' + GLASS.device(status=CONST.STATUS_OFFLINE) + ']'
         device_url = CONST.DEVICE_URL.format(device_id=GLASS.DEVICE_ID)
-        m.get(device_url, text=device_text_offline)
+        m.get(device_url, json=[GLASS.device(status=CONST.STATUS_OFFLINE)])
 
         # Logout to reset everything
         self.abode.logout()
@@ -166,23 +155,19 @@ class TestDevice:
     def tests_multiple_devices(self, m):
         """Tests that multiple devices are returned properly."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
         # Set up a list of devices
-        dev_list = (
-            '['
-            + POWERSENSOR.device()
-            + ","
-            + DOOR_CONTACT.device()
-            + ","
-            + GLASS.device()
-            + ']'
-        )
+        dev_list = [
+            POWERSENSOR.device(),
+            DOOR_CONTACT.device(),
+            GLASS.device(),
+        ]
 
-        m.get(CONST.DEVICES_URL, text=dev_list)
+        m.get(CONST.DEVICES_URL, json=dev_list)
 
         # Logout to reset everything
         self.abode.logout()
@@ -209,15 +194,12 @@ class TestDevice:
     def tests_unknown_devices(self, m):
         """Tests that multiple devices are returned properly."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
-        # Set up a list of devices
-        dev_list = '[' + UNKNOWN.device() + ']'
-
-        m.get(CONST.DEVICES_URL, text=dev_list)
+        m.get(CONST.DEVICES_URL, json=[UNKNOWN.device()])
 
         # Logout to reset everything
         self.abode.logout()
@@ -232,38 +214,34 @@ class TestDevice:
     def tests_device_category_filter(self, m):
         """Tests that device category filter returns requested results."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
         # Set up a list of devices
-        dev_list = (
-            '['
-            + POWERSENSOR.device(
+        dev_list = [
+            POWERSENSOR.device(
                 devid='ps1',
                 status=CONST.STATUS_OFF,
                 low_battery=False,
                 no_response=False,
-            )
-            + ","
-            + POWERSENSOR.device(
+            ),
+            POWERSENSOR.device(
                 devid='ps2',
                 status=CONST.STATUS_OFF,
                 low_battery=False,
                 no_response=False,
-            )
-            + ","
-            + GLASS.device(
+            ),
+            GLASS.device(
                 devid='gb1',
                 status=CONST.STATUS_OFF,
                 low_battery=False,
                 no_response=False,
-            )
-            + ']'
-        )
+            ),
+        ]
 
-        m.get(CONST.DEVICES_URL, text=dev_list)
+        m.get(CONST.DEVICES_URL, json=dev_list)
 
         # Logout to reset everything
         self.abode.logout()
@@ -283,12 +261,12 @@ class TestDevice:
     def tests_no_control_url(self, m):
         """Check that devices return false without control url's."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok())
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
 
-        m.get(CONST.DEVICES_URL, text=GLASS.device(status=CONST.STATUS_ONLINE))
+        m.get(CONST.DEVICES_URL, json=GLASS.device(status=CONST.STATUS_ONLINE))
 
         # Logout to reset everything
         self.abode.logout()
@@ -303,13 +281,13 @@ class TestDevice:
     def tests_device_status_changes(self, m):
         """Tests that device status changes work as expected."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
             CONST.DEVICES_URL,
-            text=POWERSENSOR.device(
+            json=POWERSENSOR.device(
                 devid=POWERSENSOR.DEVICE_ID,
                 status=CONST.STATUS_OFF,
                 low_battery=False,
@@ -332,7 +310,7 @@ class TestDevice:
         control_url = POWERSENSOR.CONTROL_URL
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=POWERSENSOR.DEVICE_ID, status=CONST.STATUS_ON_INT
             ),
         )
@@ -345,7 +323,7 @@ class TestDevice:
         # Change response
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=POWERSENSOR.DEVICE_ID, status=CONST.STATUS_OFF_INT
             ),
         )
@@ -358,7 +336,7 @@ class TestDevice:
         # Test that an invalid device ID in response throws exception
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid='ZW:deadbeef', status=CONST.STATUS_OFF_INT
             ),
         )
@@ -369,7 +347,7 @@ class TestDevice:
         # Test that an invalid status in response throws exception
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=POWERSENSOR.DEVICE_ID, status=CONST.STATUS_OFF_INT
             ),
         )
@@ -380,15 +358,15 @@ class TestDevice:
     def tests_device_level_changes(self, m):
         """Tests that device level changes work as expected."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
         # TODO: Test with a device that supports levels
         m.get(
             CONST.DEVICES_URL,
-            text=POWERSENSOR.device(
+            json=POWERSENSOR.device(
                 devid=POWERSENSOR.DEVICE_ID,
                 status=CONST.STATUS_OFF,
                 low_battery=False,
@@ -410,7 +388,7 @@ class TestDevice:
         # Set up control url response
         m.put(
             POWERSENSOR.CONTROL_URL,
-            text=DEVICES.level_put_response_ok(
+            json=DEVICES.level_put_response_ok(
                 devid=POWERSENSOR.DEVICE_ID, level='100'
             ),
         )
@@ -422,7 +400,7 @@ class TestDevice:
         # Change response
         m.put(
             POWERSENSOR.CONTROL_URL,
-            text=DEVICES.level_put_response_ok(devid=POWERSENSOR.DEVICE_ID, level='25'),
+            json=DEVICES.level_put_response_ok(devid=POWERSENSOR.DEVICE_ID, level='25'),
         )
 
         # Change the level to str '25'
@@ -432,7 +410,7 @@ class TestDevice:
         # Test that an invalid device ID in response throws exception
         m.put(
             POWERSENSOR.CONTROL_URL,
-            text=DEVICES.level_put_response_ok(devid='ZW:deadbeef', level='25'),
+            json=DEVICES.level_put_response_ok(devid='ZW:deadbeef', level='25'),
         )
 
         with pytest.raises(jaraco.abode.AbodeException):
@@ -441,7 +419,7 @@ class TestDevice:
         # Test that an invalid level in response throws exception
         m.put(
             POWERSENSOR.CONTROL_URL,
-            text=DEVICES.level_put_response_ok(devid=POWERSENSOR.DEVICE_ID, level='98'),
+            json=DEVICES.level_put_response_ok(devid=POWERSENSOR.DEVICE_ID, level='98'),
         )
 
         with pytest.raises(jaraco.abode.AbodeException):
@@ -450,43 +428,29 @@ class TestDevice:
     def tests_all_devices(self, m):
         """Tests that all mocked devices are mapped correctly."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
         # Create all devices
-        all_devices = (
-            '['
-            + DOOR_CONTACT.device()
-            + ','
-            + DOOR_LOCK.device()
-            + ','
-            + GLASS.device()
-            + ','
-            + IR_CAMERA.device()
-            + ','
-            + KEYPAD.device()
-            + ','
-            + PIR.device()
-            + ','
-            + POWERMETER.device()
-            + ','
-            + POWERSENSOR.device()
-            + ','
-            + REMOTE_CONTROLLER.device()
-            + ','
-            + SECUREBARRIER.device()
-            + ','
-            + SIREN.device()
-            + ','
-            + STATUS_DISPLAY.device()
-            + ','
-            + WATER_SENSOR.device()
-            + ']'
-        )
+        all_devices = [
+            DOOR_CONTACT.device(),
+            DOOR_LOCK.device(),
+            GLASS.device(),
+            IR_CAMERA.device(),
+            KEYPAD.device(),
+            PIR.device(),
+            POWERMETER.device(),
+            POWERSENSOR.device(),
+            REMOTE_CONTROLLER.device(),
+            SECUREBARRIER.device(),
+            SIREN.device(),
+            STATUS_DISPLAY.device(),
+            WATER_SENSOR.device(),
+        ]
 
-        m.get(CONST.DEVICES_URL, text=all_devices)
+        m.get(CONST.DEVICES_URL, json=all_devices)
 
         # Logout to reset everything
         self.abode.logout()
