@@ -19,13 +19,13 @@ class TestDimmer:
     def tests_dimmer_device_properties(self, m):
         """Tests that dimmer light devices properties work as expected."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
             CONST.DEVICES_URL,
-            text=DIMMER.device(
+            json=DIMMER.device(
                 devid=DIMMER.DEVICE_ID,
                 status=CONST.STATUS_OFF,
                 level=0,
@@ -58,7 +58,7 @@ class TestDimmer:
         # Change device properties
         m.get(
             device_url,
-            text=DIMMER.device(
+            json=DIMMER.device(
                 devid=DIMMER.DEVICE_ID,
                 status=CONST.STATUS_ON,
                 level=87,
@@ -79,13 +79,13 @@ class TestDimmer:
     def tests_dimmer_status_changes(self, m):
         """Tests that dimmer device changes work as expected."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
             CONST.DEVICES_URL,
-            text=DIMMER.device(
+            json=DIMMER.device(
                 devid=DIMMER.DEVICE_ID,
                 status=CONST.STATUS_OFF,
                 level=0,
@@ -109,7 +109,7 @@ class TestDimmer:
         control_url = CONST.BASE_URL + DIMMER.CONTROL_URL
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=DIMMER.DEVICE_ID, status=CONST.STATUS_ON_INT
             ),
         )
@@ -122,7 +122,7 @@ class TestDimmer:
         # Change response
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=DIMMER.DEVICE_ID, status=CONST.STATUS_OFF_INT
             ),
         )
@@ -135,7 +135,7 @@ class TestDimmer:
         # Test that an invalid status response throws exception
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=DIMMER.DEVICE_ID, status=CONST.STATUS_OFF_INT
             ),
         )
