@@ -16,13 +16,13 @@ class TestSecureBarrier:
     def tests_cover_device_properties(self, m):
         """Tests that cover devices properties work as expected."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
             CONST.DEVICES_URL,
-            text=COVER.device(
+            json=COVER.device(
                 devid=COVER.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
                 low_battery=False,
@@ -50,7 +50,7 @@ class TestSecureBarrier:
         # Change device properties
         m.get(
             device_url,
-            text=COVER.device(
+            json=COVER.device(
                 devid=COVER.DEVICE_ID,
                 status=CONST.STATUS_OPEN,
                 low_battery=True,
@@ -70,13 +70,13 @@ class TestSecureBarrier:
     def tests_cover_status_changes(self, m):
         """Tests that cover device changes work as expected."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
             CONST.DEVICES_URL,
-            text=COVER.device(
+            json=COVER.device(
                 devid=COVER.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
                 low_battery=False,
@@ -99,7 +99,7 @@ class TestSecureBarrier:
         control_url = CONST.BASE_URL + COVER.CONTROL_URL
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=COVER.DEVICE_ID, status=CONST.STATUS_OPEN_INT
             ),
         )
@@ -112,7 +112,7 @@ class TestSecureBarrier:
         # Change response
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=COVER.DEVICE_ID, status=CONST.STATUS_CLOSED_INT
             ),
         )
