@@ -19,13 +19,13 @@ class TestValve:
     def tests_switch_device_properties(self, m):
         """Tests that switch devices properties work as expected."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
             CONST.DEVICES_URL,
-            text=VALVE.device(
+            json=VALVE.device(
                 devid=VALVE.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
                 low_battery=False,
@@ -53,7 +53,7 @@ class TestValve:
         # Change device properties
         m.get(
             device_url,
-            text=VALVE.device(
+            json=VALVE.device(
                 devid=VALVE.DEVICE_ID,
                 status=CONST.STATUS_OPEN,
                 low_battery=True,
@@ -72,13 +72,13 @@ class TestValve:
     def tests_switch_status_changes(self, m):
         """Tests that switch device changes work as expected."""
         # Set up URL's
-        m.post(CONST.LOGIN_URL, text=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, text=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, text=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, text=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
+        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
             CONST.DEVICES_URL,
-            text=VALVE.device(
+            json=VALVE.device(
                 devid=VALVE.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
                 low_battery=False,
@@ -101,7 +101,7 @@ class TestValve:
         control_url = CONST.BASE_URL + VALVE.CONTROL_URL
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=VALVE.DEVICE_ID, status=CONST.STATUS_OPEN_INT
             ),
         )
@@ -114,7 +114,7 @@ class TestValve:
         # Change response
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=VALVE.DEVICE_ID, status=CONST.STATUS_CLOSED_INT
             ),
         )
@@ -127,7 +127,7 @@ class TestValve:
         # Test that an invalid status response throws exception
         m.put(
             control_url,
-            text=DEVICES.status_put_response_ok(
+            json=DEVICES.status_put_response_ok(
                 devid=VALVE.DEVICE_ID, status=CONST.STATUS_CLOSED_INT
             ),
         )
